@@ -24,7 +24,7 @@
 #ifndef __TWITUX_KEYRING_H__
 #define __TWITUX_KEYRING_H__
 
-#include <glib/gtypes.h>
+#include <glib.h>
 
 G_BEGIN_DECLS
 
