@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /*
  * Copyright (C) 2002-2007 Imendio AB
- * Copyright (C) 2007-2008 Brian Pepple <bpepple@fedoraproject.org>
+ * Copyright (C) 2007-2009 Brian Pepple <bpepple@fedoraproject.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -26,6 +26,7 @@
 #include <sys/stat.h>
 #include <string.h>
 
+#include <canberra-gtk.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <libnotify/notify.h>
@@ -55,6 +56,7 @@
 
 #ifdef HAVE_DBUS
 #include "twitux-dbus.h"
+#include <dbus/dbus-glib.h>
 #endif
 
 #define GET_PRIV(obj)           \
@@ -63,6 +65,8 @@
 #define DEBUG_DOMAIN_SETUP       "AppSetup"
 #define DEBUG_QUIT
 
+#define TYPE_TWITTER "twitter"
+
 struct _TwituxAppPriv {
 	/* Main widgets */
 	GtkWidget         *window;
@@ -94,8 +98,11 @@ struct _TwituxAppPriv {
 	GtkWidget         *popup_menu;
 	GtkToggleAction   *popup_menu_show_app;
 
-	/* Notify */
-	NotifyNotification *notification;
+	/* Account related data */
+	DBusGProxy        *accounts_service;
+    DBusGProxy        *account;
+	char              *username;
+	char              *password;
 
 	/* Misc */
 	guint              size_timeout_id;
@@ -111,6 +118,21 @@ static void	    twitux_app_class_init			 (TwituxAppClass        *klass);
 static void     twitux_app_init			         (TwituxApp             *app);
 static void     app_finalize                     (GObject               *object);
 static void     restore_main_window_geometry     (GtkWidget             *main_window);
+static void     on_accounts_destroy              (DBusGProxy            *proxy, 
+                                                  TwituxApp             *app);
+static void     disconnect                       (TwituxApp             *app);
+static void     reconnect                        (TwituxApp             *app);
+static gboolean update_account                   (DBusGProxy            *account,
+                                                  TwituxApp             *app,
+                                                  GError **error);
+static void     on_account_changed               (DBusGProxy *account,
+					                              TwituxApp *app);
+static void     on_account_disabled              (DBusGProxy *accounts,
+					                              const char *opath,
+					                              TwituxApp *app);
+static void     on_account_enabled               (DBusGProxy *accounts,
+					                              const char *opath,
+					                              TwituxApp *app);
 static void     app_setup                        (void);
 static void     main_window_destroy_cb           (GtkWidget             *window,
 												  TwituxApp             *app);
@@ -157,12 +179,15 @@ static void     app_twitux_view_friends_cb       (GtkAction             *action,
 												  TwituxApp             *app);
 static void     app_about_cb                     (GtkWidget             *window,
 												  TwituxApp             *app);
+static void     app_help_contents_cb             (GtkWidget             *widget,
+												  TwituxApp             *app);
 static void     app_status_icon_activate_cb      (GtkStatusIcon         *status_icon,
 												  TwituxApp             *app);
 static void     app_status_icon_popup_menu_cb    (GtkStatusIcon         *status_icon,
 												  guint                  button,
 												  guint                  activate_time,
 												  TwituxApp             *app);
+static gboolean request_accounts                 (TwituxApp *a, GError **error);
 static void     app_add_friend_cb                (GtkAction				*menuitem,
 												  TwituxApp             *app);
 static void     app_connection_items_setup       (TwituxApp             *app,
@@ -240,6 +265,177 @@ restore_main_window_geometry (GtkWidget *main_window)
 	twitux_geometry_load_for_main_window (main_window);
 }
 
+static void
+on_accounts_destroy (DBusGProxy *proxy, TwituxApp *app)
+{
+	TwituxAppPriv *priv = GET_PRIV (app);
+    priv->account = NULL;
+	priv->accounts_service = NULL;
+}
+
+static void
+disconnect (TwituxApp *app)
+{
+	GtkListStore *store = twitux_tweet_list_get_store ();
+	gtk_list_store_clear (store);
+	twitux_network_logout ();
+	twitux_app_state_on_connection (FALSE);
+}
+
+static void
+reconnect (TwituxApp *app)
+{
+	TwituxConf *conf;
+	gboolean login;
+
+	disconnect (app);
+	conf = twitux_conf_get ();
+
+	/*Check to see if we should automatically login */
+	twitux_conf_get_bool (conf,
+						  TWITUX_PREFS_AUTH_AUTO_LOGIN,
+						  &login);
+
+	if (!login)
+		return;
+
+	app_login (app);
+}
+
+static gboolean
+update_account (DBusGProxy  *account,
+				TwituxApp   *app,
+				GError     **error)
+{
+	TwituxAppPriv *priv;
+	gchar         *username;
+	gchar         *password;
+
+
+	priv = GET_PRIV (app);
+
+    /* the account is changing */
+    if (priv->account && strcmp (g_strdup (dbus_g_proxy_get_path (account)),
+								 g_strdup (dbus_g_proxy_get_path (priv->account))) != 0) {
+	    g_object_unref (priv->account);
+        priv->account = NULL;
+    }
+  
+    if (!priv->account) {
+        priv->account = account;
+        dbus_g_proxy_add_signal (priv->account,
+								 "Changed",
+								 G_TYPE_INVALID);
+		dbus_g_proxy_connect_signal (priv->account,
+									 "Changed",
+									 G_CALLBACK (on_account_changed),
+									 app, NULL);
+    }
+
+    /* The username should normally never change on an existing account, but let's update
+       it in any case. Since we are only interested in the enabled account,
+       and are connected to an account disabled signal, we don't need to check the 
+       enabled flag here. */		
+    if (!dbus_g_proxy_call (priv->account,
+						    "GetUsername",
+							error,
+							G_TYPE_INVALID,
+							G_TYPE_STRING,
+							&username,
+							G_TYPE_INVALID))
+        return FALSE;
+
+	if (!dbus_g_proxy_call (priv->account,
+							"GetPassword",
+							error,
+							G_TYPE_INVALID,
+							G_TYPE_STRING,
+							&password,
+							G_TYPE_INVALID))
+        return FALSE;
+
+    priv->username = username;
+	priv->password = password;
+    return TRUE;
+}               
+
+static void
+on_account_changed (DBusGProxy *account,
+					TwituxApp  *app)
+{
+	TwituxAppPriv *priv;
+	GError        *error = NULL;
+
+	priv = GET_PRIV (app);
+
+    /* we shouldn't be getting a signal about an account that is no longer current, 
+       but let's do these checks just in case */
+    if (!priv->account || strcmp (g_strdup (dbus_g_proxy_get_path (account)),
+								  g_strdup (dbus_g_proxy_get_path (priv->account))) != 0)
+		return;
+
+    if (!update_account(account, app, &error)) {
+        g_printerr ("failed to update an account that changed: %s", error->message);
+        return; 
+    }
+
+	reconnect (app);
+}
+
+static void
+on_account_disabled (DBusGProxy *accounts,
+					 const char *opath,
+					 TwituxApp  *app)
+{
+	TwituxAppPriv *priv;
+	GError        *error = NULL;
+
+	priv = GET_PRIV (app);
+
+	if (!priv->account || strcmp (opath, g_strdup (dbus_g_proxy_get_path (priv->account))) != 0)
+		return;
+
+	if (!request_accounts (app, &error)) {
+		g_warning ("Failed to get accounts: %s", error->message);
+		g_clear_error (&error);
+		return;
+	}
+
+	reconnect (app);
+}
+
+static void
+on_account_enabled (DBusGProxy *accounts,
+					const char *opath,
+					TwituxApp  *app)
+{
+	GError *error = NULL;
+	TwituxAppPriv *priv;
+	priv = GET_PRIV (app);
+	    
+    DBusGProxy *account;
+
+    account = dbus_g_proxy_new_for_name_owner (dbus_g_bus_get (DBUS_BUS_SESSION, NULL),
+											   "org.gnome.OnlineAccounts",
+											   opath,
+											   "org.gnome.OnlineAccounts", 
+                                               &error);
+
+    if (!account) {
+        g_warning ("Could not get an account object for opath: %s",
+				   opath);
+		g_clear_error (&error);
+		return;
+	}
+
+    if (!update_account(account, app, &error)) {
+        g_printerr ("failed to update an account that got enabled: %s", error->message);
+        return; 
+    }
+
+	reconnect (app);
+}
+	
 static void
 app_setup (void)
 {
@@ -252,6 +448,10 @@ app_setup (void)
 	gboolean          login;
 	gboolean		  hidden;
 
+    GError           *error = NULL;
+    guint32           result;
+    DBusGProxy       *session_bus;
+
 	twitux_debug (DEBUG_DOMAIN_SETUP, "Beginning....");
 
 	priv = GET_PRIV (app);
@@ -311,6 +511,7 @@ app_setup (void)
 						"view_direct_messages", "changed", app_view_direct_messages_cb,
 						"view_direct_replies", "changed", app_view_direct_replies_cb,
 						"view_twitux_timeline", "changed", app_twitux_timeline_cb,
+						"help_contents", "activate", app_help_contents_cb,
 						"view_friends", "activate", app_twitux_view_friends_cb,
 						"help_about", "activate", app_about_cb,
 						NULL);
@@ -327,6 +528,53 @@ app_setup (void)
 	twitux_dbus_nm_init ();
 #endif
 
+    priv->accounts_service = NULL;
+
+    session_bus = dbus_g_proxy_new_for_name (dbus_g_bus_get (DBUS_BUS_SESSION, NULL),
+                                             "org.freedesktop.DBus",
+                                             "/org/freedesktop/DBus",
+                                             "org.freedesktop.DBus");
+
+    if (dbus_g_proxy_call (session_bus, "StartServiceByName", &error,
+                           G_TYPE_STRING, "org.gnome.OnlineAccounts", 
+                           G_TYPE_UINT, 0, G_TYPE_INVALID, 
+                           G_TYPE_UINT, &result, G_TYPE_INVALID)) {
+	    priv->accounts_service =
+			dbus_g_proxy_new_for_name (dbus_g_bus_get (DBUS_BUS_SESSION, NULL),
+									   "org.gnome.OnlineAccounts",
+									   "/onlineaccounts",
+									   "org.gnome.OnlineAccounts");
+    }
+
+	if (priv->accounts_service) {
+		g_signal_connect (priv->accounts_service, "destroy",
+						  G_CALLBACK (on_accounts_destroy), app); 
+	    dbus_g_proxy_call (priv->accounts_service,
+						   "EnsureAccountType",
+						   &error,
+						   G_TYPE_STRING, TYPE_TWITTER,
+                           G_TYPE_STRING, "Twitter",
+                           G_TYPE_STRING, "Twitter username",
+                           G_TYPE_STRING, "http://twitter.com",
+						   G_TYPE_INVALID);
+		dbus_g_proxy_add_signal (priv->accounts_service,
+								 "AccountDisabled",
+								 DBUS_TYPE_G_OBJECT_PATH,
+								 G_TYPE_INVALID);
+		dbus_g_proxy_add_signal (priv->accounts_service,
+								 "AccountEnabled",
+								 DBUS_TYPE_G_OBJECT_PATH,
+								 G_TYPE_INVALID);
+		dbus_g_proxy_connect_signal (priv->accounts_service,
+									 "AccountDisabled",
+									 G_CALLBACK (on_account_disabled),
+									 app, NULL);
+		dbus_g_proxy_connect_signal (priv->accounts_service,
+									 "AccountEnabled",
+									 G_CALLBACK (on_account_enabled),
+									 app, NULL);
+	}
+
 	/* Set-up the notification area */
 	twitux_debug (DEBUG_DOMAIN_SETUP,
 				  "Configuring notification area widget...");
@@ -481,6 +729,7 @@ twitux_app_toggle_visibility (void)
 
 		gtk_window_get_size (GTK_WINDOW (priv->window), &w, &h);
 		gtk_window_get_position (GTK_WINDOW (priv->window), &x, &y);
+		gtk_widget_hide (priv->window);
 
 		twitux_geometry_save_for_main_window (x, y, w, h);
 
@@ -488,20 +737,14 @@ twitux_app_toggle_visibility (void)
 			g_source_remove (priv->size_timeout_id);
 			priv->size_timeout_id = 0;
 		}
-
-		gtk_widget_hide (priv->window);
-
-		twitux_conf_set_bool (twitux_conf_get (),
-							  TWITUX_PREFS_UI_MAIN_WINDOW_HIDDEN,
-							  TRUE);
 	} else {
 		twitux_geometry_load_for_main_window (priv->window);
 		twitux_window_present (GTK_WINDOW (priv->window), TRUE);
-
-		twitux_conf_set_bool (twitux_conf_get (),
-							  TWITUX_PREFS_UI_MAIN_WINDOW_HIDDEN,
-							  FALSE);
 	}
+	/* Save the window visibility state */
+	twitux_conf_set_bool (twitux_conf_get (),
+						  TWITUX_PREFS_UI_MAIN_WINDOW_HIDDEN,
+						  visible);
 }
 
 void
@@ -533,8 +776,7 @@ static void
 app_disconnect_cb (GtkWidget *widget,
 				   TwituxApp *app)
 {
-	twitux_network_logout ();
-	twitux_app_state_on_connection (FALSE);
+	disconnect (app);
 }
 
 static void
@@ -668,6 +910,14 @@ app_twitux_view_friends_cb (GtkAction *action,
 	twitux_lists_dialog_show (GTK_WINDOW (priv->window));
 }
 
+static char**
+get_account_set_request (TwituxApp *app)
+{
+	static const char* twitter[2] = { TYPE_TWITTER, NULL };
+
+	return (char **)twitter;
+}
+
 static void
 app_account_cb (GtkWidget *widget,
 				TwituxApp *app)
@@ -676,7 +926,17 @@ app_account_cb (GtkWidget *widget,
 
 	priv = GET_PRIV (app);
 
-	twitux_account_dialog_show (GTK_WINDOW (priv->window));
+	if (priv->accounts_service) {
+		dbus_g_proxy_call_no_reply (priv->accounts_service,
+									"OpenAccountsDialogWithTypes",
+									G_TYPE_STRV, 
+									get_account_set_request (app),
+                                    G_TYPE_UINT, 
+                                    gtk_get_current_event_time(),   
+									G_TYPE_INVALID);
+	} else {
+		twitux_account_dialog_show (GTK_WINDOW (priv->window));
+	}
 }
 
 static void
@@ -701,6 +961,17 @@ app_about_cb (GtkWidget *widget,
 	twitux_about_dialog_new (GTK_WINDOW (priv->window));
 }
 
+static void
+app_help_contents_cb (GtkWidget *widget,
+					  TwituxApp *app)
+{
+	TwituxAppPriv *priv;
+
+	priv = GET_PRIV (app);
+
+	twitux_help_show (GTK_WINDOW (priv->window));
+}
+
 static void
 app_add_friend_cb (GtkAction *item,
 				   TwituxApp *app)
@@ -758,26 +1029,47 @@ app_status_icon_popup_menu_cb (GtkStatusIcon *status_icon,
 static void
 app_status_icon_create_menu (void)
 {
-	TwituxAppPriv *priv;
-	GtkBuilder    *ui;
+	TwituxAppPriv   *priv;
+	GtkAction       *new_msg;
+	GtkAction       *quit;
+	GtkWidget       *w;
 
 	priv = GET_PRIV (app);
 
-	/* Get widgets */
-	ui =
-		twitux_xml_get_file ("tray_menu.xml",
-							 "tray_menu", &priv->popup_menu,
-							 "tray_show_app", &priv->popup_menu_show_app,
-							 NULL);
+	priv->popup_menu_show_app = gtk_toggle_action_new ("tray_show_app",
+													   _("_Show Twitux"),
+													   NULL,
+													   NULL);
+	g_signal_connect (G_OBJECT (priv->popup_menu_show_app),
+					  "toggled", G_CALLBACK (app_show_hide_cb),
+					  app);
 
-	/* Connect the signals */
-	twitux_xml_connect (ui, app,
-						"tray_new_message", "activate", app_new_message_cb,
-						"tray_quit", "activate", app_quit_cb,
-						"tray_show_app", "toggled", app_show_hide_cb,
-						NULL);
+	new_msg = gtk_action_new ("tray_new_message",
+							  _("_New Message"),
+							  NULL,
+							  "gtk-new");
+	g_signal_connect (G_OBJECT (new_msg),
+					  "activate", G_CALLBACK (app_new_message_cb),
+					  app);
 
-	g_object_unref (ui);
+	quit = gtk_action_new ("tray_quit",
+						   _("_Quit"),
+						   NULL,
+						   "gtk-quit");
+	g_signal_connect (G_OBJECT (quit),
+					  "activate", G_CALLBACK (app_quit_cb),
+					  app);
+
+	priv->popup_menu = gtk_menu_new ();
+	w = gtk_action_create_menu_item (GTK_ACTION (priv->popup_menu_show_app));
+	gtk_menu_shell_append (GTK_MENU_SHELL (priv->popup_menu), w);
+	w = gtk_separator_menu_item_new ();
+	gtk_widget_show (w);
+	gtk_menu_shell_append (GTK_MENU_SHELL (priv->popup_menu), w);
+	w = gtk_action_create_menu_item (new_msg);
+	gtk_menu_shell_append (GTK_MENU_SHELL (priv->popup_menu), w);
+	w = gtk_action_create_menu_item (quit);
+	gtk_menu_shell_append (GTK_MENU_SHELL (priv->popup_menu), w);
 }
 
 static void
@@ -856,13 +1148,95 @@ app_window_configure_event_cb (GtkWidget         *widget,
 	return FALSE;
 }
 
+static gboolean
+request_accounts (TwituxApp  *app,
+				  GError    **error)
+{
+	TwituxAppPriv  *priv;
+	guint           i;
+	GPtrArray      *accounts = NULL;
+	char          **accountset;
+    gboolean        succeeded = TRUE;
+
+	priv = GET_PRIV (app);
+
+	accountset = get_account_set_request (app);
+
+	if (!G_STR_EMPTY (priv->username)){
+		g_free (priv->username);
+	}
+	priv->username = NULL;
+
+	if (!G_STR_EMPTY (priv->password)) {
+		g_free (priv->password);
+	}
+	priv->password = NULL;
+
+    if (priv->account) 
+        g_object_unref (priv->account);
+    priv->account = NULL;
+ 
+	if (!dbus_g_proxy_call (priv->accounts_service,
+							"GetEnabledAccountsWithTypes",
+							error,
+							G_TYPE_STRV,
+							accountset,
+							G_TYPE_INVALID,
+							dbus_g_type_get_collection ("GPtrArray", DBUS_TYPE_G_PROXY),
+							&accounts,
+							G_TYPE_INVALID))
+		return FALSE;
+
+	/* We only use the first account */
+	for (i = 0; i < accounts->len && i == 0; i++) {
+        succeeded = update_account((DBusGProxy*)g_ptr_array_index (accounts, i), app, error);
+	}
+	return succeeded;
+}
+
+static void
+request_username_password (TwituxApp *a)
+{
+	TwituxAppPriv *priv;
+	TwituxConf    *conf;
+
+	priv = GET_PRIV (a);
+
+	conf = twitux_conf_get ();
+
+	if (!priv->accounts_service) {
+		g_free (priv->username);
+		priv->username = NULL;
+		twitux_conf_get_string (conf,
+								TWITUX_PREFS_AUTH_USER_ID,
+								&priv->username);
+		g_free (priv->password);
+#ifdef HAVE_GNOME_KEYRING
+		priv->password = NULL;
+		if (G_STR_EMPTY (priv->username)) {
+			priv->password = NULL;
+		} else {
+			if (!(twitux_keyring_get_password (priv->username, &priv->password))) {
+				priv->password = NULL;
+			}
+		}
+#else
+		twitux_conf_get_string (conf,
+								TWITUX_PREFS_AUTH_PASSWORD,
+								&priv->password);
+#endif
+	} else {
+		GError *error = NULL;
+		if (!request_accounts (a, &error)) {
+			g_printerr ("failed to get accounts: %s", error->message);
+		}
+	}
+}
+
 static void
 app_login (TwituxApp *a)
 {
 	TwituxAppPriv *priv;
-	TwituxConf    *conf;
-	gchar         *username;
-	gchar         *password;
 
 #ifdef HAVE_DBUS
 	gboolean connected = TRUE;
@@ -878,34 +1252,14 @@ app_login (TwituxApp *a)
 	
 	priv = GET_PRIV (a);
 
-	conf = twitux_conf_get ();
-	twitux_conf_get_string (conf,
-							TWITUX_PREFS_AUTH_USER_ID,
-							&username);
+	request_username_password (a);
 
-#ifdef HAVE_GNOME_KEYRING
-	if (G_STR_EMPTY (username)) {
-		password = NULL;
+	if (G_STR_EMPTY (priv->username) || G_STR_EMPTY (priv->password)) {
+		app_account_cb (NULL, a);
 	} else {
-		if (!(twitux_keyring_get_password (username, &password))) {
-			password = NULL;
-		}
-	}
-#else
-	twitux_conf_get_string (conf,
-							TWITUX_PREFS_AUTH_PASSWORD,
-							&password);
-#endif
-
-	if (G_STR_EMPTY (username) || G_STR_EMPTY (password)) {
-		twitux_account_dialog_show (GTK_WINDOW (priv->window));
-	} else {
-		twitux_network_login ();
+		twitux_network_login (priv->username, priv->password);
 		app_retrieve_default_timeline ();
 	}
-
-	g_free (username);
-	g_free (password);
 }
 
 /*
@@ -1059,47 +1413,53 @@ twitux_app_set_statusbar_msg (gchar *message)
 }
 
 void
-twitux_app_show_notification (gint tweets)
+twitux_app_notify_sound (void)
 {
-	TwituxAppPriv	*priv;
-	gchar			*msg;
-	gchar			*s;
-	gboolean		 notify;
+	gboolean sound;
 
-	priv = GET_PRIV (app);
+	twitux_conf_get_bool (twitux_conf_get (),
+						  TWITUX_PREFS_UI_SOUND,
+						  &sound);
+
+	if (sound) {
+		ca_context_play (ca_gtk_context_get (),
+						 0,
+						 CA_PROP_APPLICATION_NAME, g_get_application_name (),
+						 CA_PROP_EVENT_ID, "message-new-instant",
+						 CA_PROP_EVENT_DESCRIPTION, _("New tweet received"),
+						 NULL);
+	}
+}
+
+void
+twitux_app_notify (gchar *msg)
+{
+	gboolean notify;
 
-	/* Check preferences */
 	twitux_conf_get_bool (twitux_conf_get (),
 						  TWITUX_PREFS_UI_NOTIFICATION,
 						  &notify);
 
-	if (!notify || !gtk_status_icon_is_embedded (priv->status_icon))
-		return;
+	if (notify) {
+		NotifyNotification *notification;
+		GError             *error = NULL;
 
-	if (tweets > 1) {
-		s = _("tweets");
-	} else {
-		s = _("tweet");
+		notification = notify_notification_new (PACKAGE_NAME,
+												msg,
+												"twitux",
+												NULL);
+
+		notify_notification_set_timeout (notification, 8 * 1000);
+		notify_notification_show (notification, &error);
+
+		if (error) {
+			twitux_debug (DEBUG_DOMAIN_SETUP,
+						  "Error displaying notification: %s",
+						  error->message);
+			g_error_free (error);
+		}
+		g_object_unref (G_OBJECT (notification));
 	}
-
-	msg = g_strdup_printf (_("You have %i new %s."), tweets, s);
-
-	if (priv->notification!= NULL) {
-		notify_notification_close (priv->notification, NULL);
-	}
-
-	priv->notification =
-		notify_notification_new_with_status_icon (PACKAGE_NAME,
-												  msg,
-												  NULL,
-												  priv->status_icon);
-
-	g_object_set(priv->notification, "icon-name", "twitux", NULL);
-
-	notify_notification_set_timeout (priv->notification, 3000);
-	notify_notification_show (priv->notification, NULL);
-	
-	g_free (msg);
 }
 
 void
