@@ -22,7 +22,7 @@
  */
 
 #include <config.h>
-#include <gtk/gtkmain.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
 #include <libnotify/notify.h>
