@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /*
- * Copyright (C) 2007-2008 Daniel Morales <daniminas@gmail.com>
+ * Copyright (C) 2007-2009 Daniel Morales <daniminas@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -41,7 +41,7 @@
 #include "twitux-lists-dialog.h"
 
 #define DEBUG_DOMAIN	  "Network"
-#define TWITUX_HEADER_URL "http://twitux.sourceforge.net/client.xml"
+#define TWITUX_HEADER_URL "https://twitux.sourceforge.net/client.xml"
 
 typedef struct {
 	gchar        *src;
@@ -55,8 +55,6 @@ static void network_post_data		(const gchar           *url,
 									 gchar                 *formdata,
 									 SoupSessionCallback    callback);
 static gboolean	network_check_http 	(gint                   status_code);
-static gchar *network_save_data		(SoupMessage           *msg,
-									 const char            *file);
 static void network_parser_free_lists (void);
 
 /* libsoup callbacks */
@@ -100,6 +98,8 @@ static GList				*user_followers = NULL;
 static gboolean				 processing = FALSE;
 static gchar				*current_timeline = NULL;
 static guint				 timeout_id;
+static gchar                *global_username = NULL;
+static gchar                *global_password = NULL;
 
 /* This function must be called at startup */
 void
@@ -126,7 +126,7 @@ twitux_network_new (void)
 						  TWITUX_PROXY_USE,
 						  &check_proxy);
 
-	if(check_proxy) {
+	if (check_proxy) {
 		gchar *server, *proxy_uri;
 		gint port;
 
@@ -199,8 +199,10 @@ twitux_network_close (void)
 
 	g_object_unref (soup_connection);
 
-	if (current_timeline)
+	if (current_timeline) {
 		g_free (current_timeline);
+		current_timeline = NULL;
+	}
 
 	twitux_debug (DEBUG_DOMAIN, "Libsoup closed");
 }
@@ -218,10 +220,15 @@ twitux_network_stop	(void)
 
 /* Login in Twitter */
 void
-twitux_network_login (void)
+twitux_network_login (const char *username, const char *password)
 {
 	twitux_debug (DEBUG_DOMAIN, "Begin login.. ");
 
+	g_free (global_username);
+	global_username = g_strdup (username);
+	g_free (global_password);
+	global_password = g_strdup (password);
+
 	twitux_app_set_statusbar_msg (_("Connecting..."));
 
 	/* HTTP Basic Authentication */
@@ -373,41 +380,39 @@ twitux_network_get_followers (void)
 /* Get an image from servers */
 void
 twitux_network_get_image (const gchar  *url_image,
-						  const gchar  *username,
 						  GtkTreeIter   iter)
 {
-	gchar	*images_dir;
 	gchar	*image_file;
-	gchar  **split_url;
+	gchar   *image_name;
 
 	TwituxImage *image;
 
-	/* Build image file */
-	split_url = g_strsplit (url_image, "?", 2);
-	images_dir = g_build_filename (g_get_home_dir (), ".gnome2", TWITUX_CACHE_IMAGES, NULL);
-	image_file = g_strconcat (images_dir,
-							  G_DIR_SEPARATOR_S,
-							  username,
-							  "-",
-							  split_url[1],
-							  NULL);
+	/* save using the filename */
+	image_name = strrchr (url_image, '/');
+	if (image_name && image_name[1] != '\0') {
+		image_name++;
+	} else {
+		image_name = "twitux_unknown_image";
+	}
 
-	g_strfreev (split_url);
-	g_free (images_dir);
+	image_file = g_build_filename (g_get_home_dir(), ".gnome2",
+								   TWITUX_CACHE_IMAGES,
+								   image_name, NULL);
 
 	/* check if image already exists */
-	if(g_file_test (image_file, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR)) {		
+	if (g_file_test (image_file, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR)) {		
 		/* Set image from file here */
 		twitux_app_set_image (image_file, iter);
-
 		g_free (image_file);
 		return;
 	}
 
 	image = g_new0 (TwituxImage, 1);
-	image->src = image_file;
+	image->src  = g_strdup (image_file);
 	image->iter = iter;
 
+	g_free (image_file);
+
 	/* Note: 'image' will be freed in 'network_cb_on_image' */
 	network_get_data (url_image, network_cb_on_image, image);
 }
@@ -516,35 +521,6 @@ network_check_http (gint status_code)
 	return FALSE;
 }
 
-
-/* Save data to disk */
-static gchar *
-network_save_data (SoupMessage *msg,
-                   const char  *file)
-{
-	gchar *tmp_file = NULL;
-
-	/* File dir */
-	tmp_file = g_build_filename (g_get_home_dir (), ".gnome2", file, NULL);
-
-	twitux_debug (DEBUG_DOMAIN, "Saving data to: %s", tmp_file);
-
-	/* Save */
-	if (g_file_set_contents (tmp_file,
-							 msg->response_body->data,
-							 msg->response_body->length,
-							 NULL)) {
-		return tmp_file;
-	}
-	
-	twitux_app_set_statusbar_msg (_("Failed to save cache file."));
-
-	g_free (tmp_file);
-
-	return NULL;
-}
-
-
 /* Callback to free every element on a User list */
 static void
 network_free_user_list_each (gpointer user,
@@ -591,41 +567,15 @@ network_cb_on_auth (SoupSession  *session,
 					gboolean      retrying,
 					gpointer      data)
 {
-	TwituxConf *conf;
-	gchar      *user_id;
-	gchar      *user_passwd;
-
-	conf = twitux_conf_get ();
-
-	twitux_conf_get_string (conf,
-							TWITUX_PREFS_AUTH_USER_ID,
-							&user_id);
 	/* Don't bother to continue if there is no user_id */
-	if (G_STR_EMPTY (user_id)) {
+	if (G_STR_EMPTY (global_username)) {
 		return;
 	}
 
-#ifdef HAVE_GNOME_KEYRING
-	if (!twitux_keyring_get_password (user_id, &user_passwd))
-	{
-		twitux_app_set_statusbar_msg (
-					_("Could not retrieve password from keyring."));						 	
-	}
-#else
-	twitux_conf_get_string (conf,
-							TWITUX_PREFS_AUTH_PASSWORD,
-							&user_passwd);
-#endif
-
 	/* verify that the password has been set */
-	if (!G_STR_EMPTY (user_passwd))
-		soup_auth_authenticate (auth, user_id, user_passwd);
-	
-	if (user_id)
-		g_free (user_id);
-
-	if (user_passwd)
-		g_free (user_passwd);
+	if (!G_STR_EMPTY (global_password))
+		soup_auth_authenticate (auth, global_username, 
+								global_password);
 }
 
 
@@ -683,7 +633,6 @@ network_cb_on_timeline (SoupSession *session,
 						SoupMessage *msg,
 						gpointer     user_data)
 {
-	gchar        *file;
 	gchar        *new_timeline = NULL;
 	
 	if (user_data){
@@ -705,15 +654,10 @@ network_cb_on_timeline (SoupSession *session,
 		return;
 	}
 
-	/* Save */
-	file = network_save_data (msg, TWITUX_CACHE_FILE);
-	if (!file)
-		return;
-
-	twitux_debug (DEBUG_DOMAIN, "Parsing timeline: %s",file);
+	twitux_debug (DEBUG_DOMAIN, "Parsing timeline");
 
 	/* Parse and set ListStore */
-	if (twitux_parser_timeline (file)) {
+	if (twitux_parser_timeline (msg->response_body->data, msg->response_body->length)) {
 		twitux_app_set_statusbar_msg (_("Timeline Loaded"));
 
 		if (new_timeline){
@@ -727,8 +671,6 @@ network_cb_on_timeline (SoupSession *session,
 
 	if (new_timeline)
 		g_free (new_timeline);
-
-	g_free (file);
 }
 
 
@@ -740,7 +682,6 @@ network_cb_on_users (SoupSession *session,
 {
 	gboolean  friends = GPOINTER_TO_INT(user_data);
 	GList    *users;
-	gchar    *file;
 		
 	twitux_debug (DEBUG_DOMAIN,
 				  "Users response: %i",msg->status_code);
@@ -748,16 +689,12 @@ network_cb_on_users (SoupSession *session,
 	/* Check response */
 	if (!network_check_http (msg->status_code))
 		return;
-	
-	/* Save */
-	file = network_save_data (msg, TWITUX_CACHE_USERS);
-	if (!file)
-		return;
 
 	/* parse user list */
-	twitux_debug (DEBUG_DOMAIN, "Parsing user list: %s",file);
+	twitux_debug (DEBUG_DOMAIN, "Parsing user list");
 
-	users = twitux_parser_users_list (file);
+	users = twitux_parser_users_list (msg->response_body->data,
+									  msg->response_body->length);
 
 	/* check if it ok, and if it is a followers or following list */
 	if (users && friends){
@@ -771,8 +708,6 @@ network_cb_on_users (SoupSession *session,
 	} else {
 		twitux_app_set_statusbar_msg (_("Users parser error."));
 	}
-
-	g_free (file);
 }
 
 
@@ -811,7 +746,6 @@ network_cb_on_add (SoupSession *session,
 				   gpointer     user_data)
 {
 	TwituxUser *user;
-	gchar *file;
 
 	twitux_debug (DEBUG_DOMAIN,
 				  "Add user response: %i", msg->status_code);
@@ -820,15 +754,11 @@ network_cb_on_add (SoupSession *session,
 	if (!network_check_http (msg->status_code))
 		return;
 
-	/* Save */
-	file = network_save_data (msg, TWITUX_CACHE_USERS);
-	if (!file)
-		return;
-
 	/* parse new user */
-	twitux_debug (DEBUG_DOMAIN, "Parsing new user: %s",file);
+	twitux_debug (DEBUG_DOMAIN, "Parsing new user");
 
-	user = twitux_parser_single_user (file);
+	user = twitux_parser_single_user (msg->response_body->data,
+									  msg->response_body->length);
 
 	if (user) {
 		user_friends = g_list_append ( user_friends, user );
@@ -836,8 +766,6 @@ network_cb_on_add (SoupSession *session,
 	} else {
 		twitux_app_set_statusbar_msg (_("Failed to add user"));
 	}
-	
-	g_free (file);
 }
 
 
@@ -880,7 +808,8 @@ network_timeout_new (void)
 						 TWITUX_PREFS_TWEETS_RELOAD_TIMELINES,
 						 &minutes);
 
-	if (minutes == 0){
+	/* The timeline reload interval shouldn't be less than 3 minutes */
+	if (minutes < 3) {
 		minutes = 3;
 	}
 
