@@ -27,6 +27,7 @@
 #include <string.h>
 
 #include <glib/gi18n.h>
+#include <gtk/gtkbuilder.h>
 #include <gtk/gtkcellrenderertext.h>
 #include <gtk/gtkdialog.h>
 #include <gtk/gtklabel.h>
@@ -34,13 +35,15 @@
 #include <gtk/gtktreeview.h>
 #include <gtk/gtktreeselection.h>
 #include <gtk/gtksizegroup.h>
-#include <glade/glade.h>
 
-#include "twitux-glade.h"
+#include <libtwitux/twitux-xml.h>
+
 #include "twitux-send-message-dialog.h"
 #include "twitux-spell.h"
 #include "twitux-spell-dialog.h"
 
+#define XML_FILE "spell_dlg.xml"
+
 typedef struct {
 	GtkWidget   *window;
 	GtkWidget   *button_replace;
@@ -225,7 +228,7 @@ twitux_spell_dialog_show (GtkWidget   *textview,
 						  const gchar *word)
 {
 	TwituxSpellDialog *dialog;
-	GladeXML          *gui;
+	GtkBuilder        *ui;
 	gchar             *str;
 
 	g_return_if_fail (textview != NULL);
@@ -240,31 +243,32 @@ twitux_spell_dialog_show (GtkWidget   *textview,
 	dialog->start = start;
 	dialog->end = end;
 
-	gui = twitux_glade_get_file ("spell_dialog.glade",
-								 "spell_dialog",
-								 NULL,
-								 "spell_dialog", &dialog->window,
-								 "button_replace", &dialog->button_replace,
-								 "label_word", &dialog->label_word,
-								 "treeview_words", &dialog->treeview_words,
-								 NULL);
+	/* Get widgets */
+	ui = twitux_xml_get_file (XML_FILE,
+						"spell_dialog", &dialog->window,
+						"button_replace", &dialog->button_replace,
+						"label_word", &dialog->label_word,
+						"treeview_words", &dialog->treeview_words,
+						NULL);
 
-	twitux_glade_connect (gui,
-						  dialog,
-						  "spell_dialog", "response", spell_dialog_response_cb,
-						  "spell_dialog", "destroy", spell_dialog_destroy_cb,
-						  NULL);
+	/* Connect the signals */
+	twitux_xml_connect (ui, dialog,
+						"spell_dialog", "destroy", spell_dialog_destroy_cb,
+						"spell_dialog", "response", spell_dialog_response_cb,
+						NULL);
 
-	g_object_unref (gui);
+	g_object_unref (ui);
 
+	/* Set the label */
 	str = g_strdup_printf ("%s:\n<b>%s</b>",
 						   _("Suggestions for the word"),
 						   word);
-
 	gtk_label_set_markup (GTK_LABEL (dialog->label_word), str);
 	g_free (str);
 
+	/* Setup the list */
 	spell_dialog_model_setup (dialog);
 
+	/* Now let's show it */
 	gtk_widget_show (dialog->window);
 }
