@@ -21,12 +21,13 @@
 #ifndef __TWITUX_UI_UTILS_H__
 #define __TWITUX_UI_UTILS_H__
 
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 
 /* Windows */
 gboolean     twitux_window_get_is_visible          (GtkWindow        *window);
 gboolean     twitux_window_get_is_present          (GtkWindow        *window);
 void         twitux_window_present                 (GtkWindow        *window,
 													gboolean          steal_focus);
+void         twitux_help_show                      (GtkWindow        *parent);
 
 #endif /*  __TWITUX_UI_UTILS_H__ */
