@@ -29,11 +29,11 @@ G_BEGIN_DECLS
 #define G_STR_EMPTY(x) ((x) == NULL || (x)[0] == '\0')
 
 /* Twitter Timelines */
-#define TWITUX_API_TIMELINE_PUBLIC	"http://twitter.com/statuses/public_timeline.xml"
-#define TWITUX_API_TIMELINE_FRIENDS	"http://twitter.com/statuses/friends_timeline.xml"
-#define TWITUX_API_TIMELINE_MY		"http://twitter.com/statuses/user_timeline.xml"
-#define TWITUX_API_TIMELINE_USER	"http://twitter.com/statuses/user_timeline/%s.xml"
-#define TWITUX_API_TIMELINE_TWITUX	"http://twitter.com/statuses/user_timeline/twitux.xml"
+#define TWITUX_API_TIMELINE_PUBLIC	"https://twitter.com/statuses/public_timeline.xml"
+#define TWITUX_API_TIMELINE_FRIENDS	"https://twitter.com/statuses/friends_timeline.xml"
+#define TWITUX_API_TIMELINE_MY		"https://twitter.com/statuses/user_timeline.xml"
+#define TWITUX_API_TIMELINE_USER	"https://twitter.com/statuses/user_timeline/%s.xml"
+#define TWITUX_API_TIMELINE_TWITUX	"https://twitter.com/statuses/user_timeline/twitux.xml"
 
 /* Twitux GConf Keys */
 #define TWITUX_PREFS_PATH "/apps/twitux"
@@ -53,6 +53,7 @@ G_BEGIN_DECLS
 #define TWITUX_PREFS_UI_MAIN_WINDOW_HIDDEN	  TWITUX_PREFS_PATH "/ui/main_window_hidden"
 #define TWITUX_PREFS_UI_EXPAND_MESSAGES       TWITUX_PREFS_PATH "/ui/expand_messages"
 #define TWITUX_PREFS_UI_NOTIFICATION          TWITUX_PREFS_PATH "/ui/notify"
+#define TWITUX_PREFS_UI_SOUND                 TWITUX_PREFS_PATH "/ui/sound"
 #define TWITUX_PREFS_UI_SPELL_LANGUAGES       TWITUX_PREFS_PATH "/ui/spell_checker_languages"
 #define TWITUX_PREFS_UI_SPELL                 TWITUX_PREFS_PATH "/ui/spell"
 
@@ -69,8 +70,6 @@ G_BEGIN_DECLS
 
 /* File storage */
 #define TWITUX_DIRECTORY                      "twitux"
-#define TWITUX_CACHE_FILE                     TWITUX_DIRECTORY "/parser.xml"
-#define TWITUX_CACHE_USERS                    TWITUX_DIRECTORY "/userslist.xml"
 #define TWITUX_CACHE_IMAGES                   TWITUX_DIRECTORY "/avatars"
 
 /* ListStore columns */
